KeyCodeClass

Enum KeyCodeClass 

pub enum KeyCodeClass {
    WritingSystem,
    Functional,
    ControlPad,
    ArrowPad,
    Numpad,
    Function,
    Media,
    Legacy,
    Gamepad,
    NonStandard,
}
Every KeyCode is grouped into one of these classes.

Variants



WritingSystem

The writing system keys are those that change meaning (i.e., they produce different key values) based on the current locale and keyboard layout.



Functional

The functional keys (not to be confused with the function keys described later) are those keys in the alphanumeric section that provide general editing functions that are common to all locales (like Shift, Tab, Enter and Backspace). With a few exceptions, these keys do not change meaning based on the current keyboard layout.



ControlPad

The control pad section of the keyboard is the set of (usually 6) keys that perform navigating and editing operations, for example, Home, PageUp and Insert.



ArrowPad

The arrow pad contains the 4 arrow keys. The keys are commonly arranged in an “upside-down T” configuration.



Numpad

The numpad section is the set of keys on the keyboard arranged in a grid like a calculator or mobile phone. This section contains numeric and mathematical operator keys. Often this section will contain a NumLock key which causes the keys to switch between the standard numeric functions and mimicking the keys of the control pad and arrow pad. Laptop computers and compact keyboards will commonly omit these keys to save space.



Function

The function section runs along the top of the keyboard (above the alphanumeric section) and contains the function keys and a few additional special keys (for example, Esc and Print Screen).



Media

Media keys are extra keys added to a keyboard that provide media related functionality like play, pause or volume control. These keys do not have a standard location on the keyboard so keyboards from different manufacturers are likely to have a different arrangement of keys or a completely different sets of keys.



Legacy

These keys are not found on modern standard keyboards. They are listed here for reference purposes.



Gamepad

These buttons are found on gamepads.



NonStandard

These keys are supported by some browsers.

Implementations

Source

impl KeyCodeClass

pub const fn name(self) -> &'static str

Returns the name of the key code.